Function parse_gemfile
pub fn parse_gemfile(
content: &str,
doc_uri: &Uri,
) -> Result<BundlerParseResult, BundlerError>Expand description
Parses a Gemfile and extracts all dependencies with positions.
pub fn parse_gemfile(
content: &str,
doc_uri: &Uri,
) -> Result<BundlerParseResult, BundlerError>Parses a Gemfile and extracts all dependencies with positions.