Struct ParsedDependency
pub struct ParsedDependency {
pub name: String,
pub name_range: Range,
pub version_req: Option<String>,
pub version_range: Option<Range>,
pub features: Vec<String>,
pub features_range: Option<Range>,
pub source: DependencySource,
pub section: DependencySection,
}Expand description
Parsed dependency from Cargo.toml with position tracking.
Stores all information about a dependency declaration, including its name, version requirement, features, and source positions for LSP operations. Positions are critical for features like hover, completion, and inlay hints.
Examples
use deps_cargo::types::{ParsedDependency, DependencySection};
use deps_cargo::DependencySource;
use tower_lsp_server::ls_types::{Position, Range};
let dep = ParsedDependency {
name: "serde".into(),
name_range: Range::new(Position::new(5, 0), Position::new(5, 5)),
version_req: Some("1.0".into()),
version_range: Some(Range::new(Position::new(5, 9), Position::new(5, 14))),
features: vec!["derive".into()],
features_range: None,
source: DependencySource::Registry,
section: DependencySection::Dependencies,
};
assert_eq!(dep.name, "serde");
assert!(matches!(dep.source, DependencySource::Registry));Fields
name: Stringname_range: Rangeversion_req: Option<String>version_range: Option<Range>features: Vec<String>features_range: Option<Range>source: DependencySourcesection: DependencySectionTrait Implementations
impl Clone for ParsedDependency
impl Clone for ParsedDependency
fn clone(&self) -> ParsedDependency
fn clone(&self) -> ParsedDependency
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for ParsedDependency
impl Debug for ParsedDependency
impl Dependency for ParsedDependency
impl Dependency for ParsedDependency
fn name_range(&self) -> Range
fn name_range(&self) -> Range
LSP range of the dependency name
fn version_requirement(&self) -> Option<&str>
fn version_requirement(&self) -> Option<&str>
Version requirement string (e.g., “^1.0”, “>=2.0”)
fn version_range(&self) -> Option<Range>
fn version_range(&self) -> Option<Range>
LSP range of the version string
fn source(&self) -> DependencySource
fn source(&self) -> DependencySource
Dependency source (registry, git, path)
impl DependencyInfo for ParsedDependency
impl DependencyInfo for ParsedDependency
fn name_range(&self) -> Range
fn name_range(&self) -> Range
LSP range of the dependency name in the source file.
fn version_requirement(&self) -> Option<&str>
fn version_requirement(&self) -> Option<&str>
Version requirement string (e.g., “^1.0”, “~2.3.4”).
fn version_range(&self) -> Option<Range>
fn version_range(&self) -> Option<Range>
LSP range of the version string (for inlay hints positioning).
fn source(&self) -> DependencySource
fn source(&self) -> DependencySource
Dependency source (registry, git, path).
impl PartialEq for ParsedDependency
impl PartialEq for ParsedDependency
impl Eq for ParsedDependency
impl StructuralPartialEq for ParsedDependency